summaryrefslogtreecommitdiffstats
path: root/kmail/kmfolder.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-02-16 20:17:18 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-02-16 20:17:18 +0000
commitf4fae92b6768541e2952173c3d4b09040f95bf7e (patch)
treed8c5d93232235cd635f3310b4d95490df181ba2d /kmail/kmfolder.h
parent125c0a08265b75a133644d3b55f47e37c919f45d (diff)
downloadtdepim-f4fae92b6768541e2952173c3d4b09040f95bf7e.tar.gz
tdepim-f4fae92b6768541e2952173c3d4b09040f95bf7e.zip
Moved kpilot from kdepim to applications, as the core Trinity libraries should not contain hardware-dependent software
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1221127 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmail/kmfolder.h')
-rw-r--r--kmail/kmfolder.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/kmail/kmfolder.h b/kmail/kmfolder.h
index 3ff1d67d..77979b98 100644
--- a/kmail/kmfolder.h
+++ b/kmail/kmfolder.h
@@ -53,7 +53,7 @@ namespace KMail {
}
using KMail::AttachmentStrategy;
-typedef TQValueList<Q_UINT32> SerNumList;
+typedef TQValueList<TQ_UINT32> SerNumList;
/** Mail folder.
* (description will be here).
@@ -272,7 +272,7 @@ public:
contained by this folder */
int countUnreadRecursive();
/** Called by KMMsgBase::setStatus when status of a message has changed
required to keep the number unread messages variable current. */
void msgStatusChanged( const KMMsgStatus oldStatus,
const KMMsgStatus newStatus,
@@ -337,7 +337,7 @@ public:
/** Change the dirty flag. */
void setDirty(bool f);
- /** Returns true if the folder contains deleted messages */
+ /** Returns true if the folder tqcontains deleted messages */
bool needsCompacting() const;
void setNeedsCompacting(bool f);
@@ -489,10 +489,10 @@ public:
int writeIndex( bool createEmptyIndex = false );
/** Set the status of the message at index @p idx to @p status. */
- void setStatus(int idx, KMMsgStatus status, bool toggle=false);
+ void seStatus(int idx, KMMsgStatus status, bool toggle=false);
/** Set the status of the message(s) in the TQValueList @p ids to @p status. */
- void setStatus(TQValueList<int>& ids, KMMsgStatus status, bool toggle=false);
+ void seStatus(TQValueList<int>& ids, KMMsgStatus status, bool toggle=false);
/** Icon related methods */
bool useCustomIcons() const { return mUseCustomIcons; }
@@ -541,7 +541,7 @@ public:
/**
* Returns true if the name is valid for a child of this folder.
- * If the name contains invalid characters then false is returned and message will contain
+ * If the name tqcontains invalid characters then false is returned and message will contain
* an explanation that can be presented to the user.
*/
bool isValidName( const TQString &folderName, TQString &message );
@@ -573,7 +573,7 @@ signals:
void shortcutChanged( KMFolder * );
/** Emitted before a message is removed from the folder. */
- void msgRemoved(KMFolder*, Q_UINT32 sernum);
+ void msgRemoved(KMFolder*, TQ_UINT32 sernum);
/** Emitted after a message is removed from the folder. */
void msgRemoved( int idx, TQString msgIdMD5 );
@@ -581,10 +581,10 @@ signals:
/** Emitted when a message is added from the folder. */
void msgAdded(int idx);
- void msgAdded(KMFolder*, Q_UINT32 sernum);
+ void msgAdded(KMFolder*, TQ_UINT32 sernum);
/** Emitted, when the status of a message is changed */
- void msgChanged(KMFolder*, Q_UINT32 sernum, int delta);
+ void msgChanged(KMFolder*, TQ_UINT32 sernum, int delta);
/** Emitted when a field of the header of a specific message changed. */
void msgHeaderChanged(KMFolder*, int);
@@ -272,7 +272,7 @@ public:
contained by this folder */
int countUnreadRecursive();
- /** Called by KMMsgBase::setStatus when status of a message has changed
+ /** Called by KMMsgBase::seStatus when status of a message has changed
required to keep the number unread messages variable current. */
void msgStatusChanged( const KMMsgStatus oldStatus,